/* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
/************************************************

  rbgiversion.h -

  This file was generated by mkmf-gnome.rb.

************************************************/

#ifndef __RBGI_VERSION_H__
#define __RBGI_VERSION_H__

#define GI_MAJOR_VERSION (1)
#define GI_MINOR_VERSION (72)
#define GI_MICRO_VERSION (0)

#define GI_CHECK_VERSION(major,minor,micro)    \
    (GI_MAJOR_VERSION > (major) || \
     (GI_MAJOR_VERSION == (major) && GI_MINOR_VERSION > (minor)) || \
     (GI_MAJOR_VERSION == (major) && GI_MINOR_VERSION == (minor) && \
      GI_MICRO_VERSION >= (micro)))


#endif /* __RBGI_VERSION_H__ */
